# Trending Repos: Agent Quality Rankings

Generated by agentkit-cli v0.36.1 | 2026-03-17 17:07 UTC

10
Repos Analyzed
43
Avg Score
garrytan/gstack
Top Scorer

Rank | Repo | Stars | Score | Grade
--- | --- | --- | --- | ---
#1 | garrytan/gstack | ⭐ 19,578 | 100 | A
#2 | webadderall/Recordly | ⭐ 2,284 | 100 | A
#3 | THU-MAIC/OpenMAIC | ⭐ 3,818 | 29 | F
#4 | aiming-lab/AutoResearchClaw | ⭐ 3,272 | 29 | F
#5 | NVIDIA/NemoClaw | ⭐ 3,255 | 29 | F
#6 | calesthio/Crucix | ⭐ 2,825 | 29 | F
#7 | davebcn87/pi-autoresearch | ⭐ 2,052 | 29 | F
#8 | pasky/chrome-cdp-skill | ⭐ 2,023 | 29 | F
#9 | TianyiDataScience/openclaw-control-center | ⭐ 2,010 | 29 | F
#10 | gsd-build/gsd-2 | ⭐ 1,653 | 29 | F